@@ -159,11 +159,12 @@
 	#
 	# Execute the command
 	#
-		ade4TkGUIFlag <<- 1
+#		ade4TkGUIFlag <<- 1
+		assign("ade4TkGUIFlag", 1, envir=.GlobalEnv)
 		mydudi <- eval.parent(cmd)
 		assign(eval(dudiname), mydudi, pos=1)
 		dialog.dudi.display(show, history, eval(dudiname))
-		rm(ade4TkGUIFlag, envir=.GlobalEnv)
+		rm("ade4TkGUIFlag", envir=.GlobalEnv)
 		if (history) {
 			commande = paste(eval(dudiname), " <- ", deparse(cmd, width = 500), sep = "")
 			rewriteHistory(commande)
